@@ -98,6 +98,11 @@ data_cfg = dict(
 
 train_pipeline = [
     dict(type='LoadImageFromFile'),
+    dict(
+        type='TopDownGetBboxCenterScale',
+        padding=1.0,
+        shift_prob=0.3,
+        shift_factor=0.2),
     dict(type='TopDownRandomFlip', flip_prob=0.5),
     dict(
         type='TopDownHalfBodyTransform',
@@ -123,6 +128,7 @@ train_pipeline = [
 
 val_pipeline = [
     dict(type='LoadImageFromFile'),
+    dict(type='TopDownGetBboxCenterScale', padding=1.0),
     dict(type='TopDownAffine'),
     dict(type='ToTensor'),
     dict(
